@@ -634,6 +634,7 @@ symbols! {
         impl_macros,
         impl_trait_in_bindings,
         import_shadowing,
+        imported_main,
         in_band_lifetimes,
         include,
         include_bytes,
@@ -781,6 +782,7 @@ symbols! {
         no,
         no_builtins,
         no_core,
+        no_coverage,
         no_crate_inject,
         no_debug,
         no_default_passes,
@@ -852,8 +854,7 @@ symbols! {
         partial_ord,
         passes,
         pat,
-        pat2015,
-        pat2021,
+        pat_param,
         path,
         pattern_parentheses,
         phantom_data,
